bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 6. Aventiure
___________________________________________________
| ### <E> kvneginne gesezen vber se ### ir geliche enheine man wesse ninder me ### div was vnmazen scoene vil michel was ir chraft ### si scoz mit snelln degenen vmb minne den scaft ### Den stein den warf si verre dar nach si witen spranch ### swer ir minne gerte der mvose ane wanch ### driv spil an gewinnen der frovwen wol geboren ### gebrast im an dem einem er hete daz hovbet sin verloren
###### 326 | ### Des het div ivnchfrovwe vnmazen vil getan ### daz gehorte bi dem Rine ein riter wolgetan ### der wande sine sinne an daz scoene wip ### dar vmbe mvosen helede sit verliesen den lip
###### 327 | ### Do sprach der vogt von Rine ich wil nider an den se ### hin ce Prvnhilde swi ez mir erge ### ich wil dvrch ir minne wagen minen lip ### den wil ich verliesen sine werde min wip
| ### Daz wil ich wider raten sprach do Sivrit ### ia hat div kvneginne so vreisliche sit ### swer vmb ir minne wirbet daz ez im hohe stat ### des mvget ir der reise habn wærlichen rat
###### 329 | ### So wil <ih> iv daz raten sprach do Hagene ### ir bittet Sivride mit iv ce tragene ### di vil starchn swære daz ist nv min rat ### sit im daz ist so chvendech wi ez vm Prvenhilde stat
###### 330 | ### Er sprach wil dv mir helfen edel Sivrit ### werbn die minnechlichen tvostv des ich dich bit ### vn– wirt mir ceime trvote <daz> minnechliche wip ### ich wil dvrch dinen willen wagen ere vn– lip
###### 331 | ### <· es> antwrte Sivrit der Sigmvndes svn ### gistv mir dine swester so wil ich ez tv^n ### di scoenen Chrimhilde ein kvneginne her ### so ger ich deheines lônes nach minen arbeiten mer
###### 332 | ### Daz lob ich sprach do Gvnther Sivrit an dine hant ### vn– chvmt div scoene Prvenhilt her in dizze lant ### so wil ich dir ce wibe mine swester gebn ### so mahtv mit der scoenen immer vroeliche lebn
###### 333 | ### Des sworen si do eide di rechen vil her ### <des> wart ir arbeiten verre deste mer ### ê daz si di frovwen brahten an den Rin ### des mvsen di vil chvenen sit in grozen sorgen sin
| ### <Sivrit> der mvose fveren di kappen mit im dan ### di der helt vil chvene mit sorgen gewan ### ab eime getwerge daz hiez Albrich ### sich bereiten zvo der verte di rechen chven vnd rich
###### 335 | ### Also der starche Sivrit di Tarnkappen trvoch ### so het er dar inne chrefte genvoch ### wol zwelf manne sterche zvo sin selbes lip ### er warp mit grozen listen daz vil herliche wip [305b]
###### 336 | ### Ovch was div selbe Tarnhv^t also getan ### daz dar inne worhte ein ieslicher man ### swaz er selbe wolde daz in doch niemen sach ### svss gewan er Prvenhilde da von im leide geschach
| ### Nv sag mir degen Sivrit ê daz min vart erge ### daz wir mit wollen ern chomn an den se ### svlen wir iht rechen fveren in Prvenhilde lant ### drizech tvsent degene di werdent sciere besant
###### 338 | ### Swie vil wir volches fveren sprach aber Sivrit ### ez pfligt div kvneginne so vreislicher sit ### di mvosen doch ersterben von ir vbermvot ### ich sol ivch baz bewisen degen chvene vnd gvot
###### 339 | ### Wir svln in rechen wise ce tal varen den Rin ### die wil ich dir benennen di daz svlen sin ### selbe vierde degene varn wir an den sê ### so erwerbn wir di frovwen swi ez vns darnach erge
###### 340 | ### Der gesellen bin ich einer daz ander soltv wesn ### der dritte daz si Hagene wir mvgen wol genesen ### der vierde daz si Danchwart der vil chvene man ### vns endvrfen andr tvosent mit strite nimmer bestan
| ### <Div> mære wess ich gerne sprach der kvnech do ### ê daz wir hinnen fveren des wære ich harte vro ### waz wir chleider solden vor Prvenhilde tragn ### div vns da wol gezæmn daz svlt ir Gvnthere sagn
###### 342 | ### Wat die aller besten di ieman bevant ### die treit man zallen citen in Prvenhilde lant ### des svlen wir richiv chleider vor der frovwen tragn ### daz wirs iht haben scande so man div mære hoere sagen
###### 343 | ### Do sprach der degen gvoter so wil ich selbe gan ### zvo miner lieben mvoter ob ich erbitten chan ### daz vns ir scoenen meide helfen prveuen chleit ### di wir tragn mit ern fver di herlichen meit
###### 344 | ### Do sprach von Tronege Hagne mit herlichen siten ### waz welt ir iwer mvoter soelher dienste biten ### lat iwer swester hoeren wes ir habet mvot ### so wirdet iv ir dienest zvo dirre hove reise gvot
| ### <Do> enbot er siner swester daz er si wolde sehn ### vn– ovch der degen Sivrit ê daz was gescehn ### do het sich div scoene ce wnsche wol gechleit ### daz chomn der vil chvenen daz was ir mæzliche leit
###### 346 | ### Nv was ovch ir gesinde gezieret als im zam ### di fversten chômn beide do si daz vernam ### do stvont si von dem sedele mit zvehten si do gie ### da si <den> gast vil edele vn– ovch ir brvoder enpfie
###### 347 | ### Willechomn si min brvoder vn– der geselle sin ### div mære ich wiste gerne so sprach <daz> magedin ### waz ir herrn woldet sit ir ce hove gat ### daz lazet ir mich hoeren wi ez iv edelen rechen stat
###### 348 | ### Do sprach der kvnech Gvnther frovwe ich wilz iv sagn ### wir mvezzen michel sorgen bi hohem [306a] mvote tragn ### wir wellen hoefscen riten verre in vremdiv lant ### wir solten zvo der reise haben cierlich gewant
| ### <Nv> sizzet lieber brvoder sprach daz kvneges kint ### vn– lat mich rehte hoeren wer di frovwen sint ### der ir da gert mit minnen in ander chvnege lant ### di v^z erwelten beide nam div frovwe bi der hant
###### 350 | ### Do gie si mit inbeiden da si ê da saz ### vof matrazze div vil richen ich wil wol wizen daz ### geworht von gvoten bilden mit golde wol erhabn ### si mohten bi den frovwen gvote chvrz wile habn
###### 351 | ### Friwentliche bliche vn– gvotlichez sehn ### des mohte da in beiden harte vil gescehn ### er trvoch si ime hercen si was im so der lip ### sit wart div scoene Chrimhilt des starchen Sivrides wip
| ### <Do> sprach der kvnech riche vil liebiv swester min ### ane dine helfe chvnd ez niht gesin ### wir wellen chvrzwilen in Prvenhilde lant ### da bedorften wir ce habene vor frovwen herlich gewant
###### 353 | ### Do sprach div ivnchfrovwe vil lieber brvoder min ### swaz der minen helfe dar an chan gesin ### des bring ich ivch wol innen daz ich iv bin bereit ### versagt iv ander iemen daz wære <Chrimhilde> leit
###### 354 | ### Ir svlt mich riter edele niht sorgende biten ### ir svlt mir gebieten mit herlichen siten ### swaz iv von mir gevalle des bin ich iv bereit ### vnt tvon ez willechliche sprach div wnnechlichiv meit
| ### <Wir> wellen liebeiv swester tragn gvot gewant ### daz sol helfen prveuen iwer edeliv hant ### des vol ziehen iwer magede daz ez vns rehte stat ### wand wir der verte han deheiner slahte rat
###### 356 | ### Do sprach div ivnchfrovwe nv merchet waz ich sage ### ich han selbe siden nv scaffet daz man trage ### gesteine vns v^f den scilden so wrchen wir div chleit ### des willen was do Gvnther vn– ovch Sivrit bereit
###### 357 | ### Wer sint die gesellen sprach div kvnegin ### di mit iv gechleidet ce hove svlen sin ### er sprach ich selbe vierde zwene mine man ### Danchwart vn– Hagene svln ce hove mit mir gan
###### 358 | ### Ir svlt vil rehte merchen waz ich iv frovwe sage ### daz ich selbe vierde ce viertagen trage ### ie drier hande chleider vn– also gvot gewant ### daz wir ane scande rv^men Prvenhilde lant
| ### Mit gvotem vrlovbe di herrn schieden dan ### do hiez ir ivnchfrovwen drizech meide gan ### v^z ir chemnaten Chrimhilt div kvnegin ### di zvo soelhem werche heten groezlichen sin
###### 360 | ### Die Arabischen siden wiz also der snê ### vnt von Zazamanch der gvoten grven alsam der [306b] chle ### dar in si leiten steine des wrden gvotiv chleit ### selbe sneit si Chrimhilt div vil herliche meit
###### 361 | ### Von vremder vissce hivten. bezoch wolgetan ### ce sehene vremden livten. swaz man der gewan ### die dachten si mit siden so sise solden tragn ### nv hoeret michel wnder von der liehten wæte sagn
| ### <Von> Marroch voz dem lande vnd ovch von Lybian ### die aller bestn siden di ie mer gewan ### deheines kvnegs chvenne der heten si genvoch ### wol lie daz scinen Chrimhilt daz si in holden willen trvoch
###### 363 | ### Sit si der hohen verte heten nv gegert ### hærmine vedern di dvhten si vnwert ### pfellel dar ob lagen swarz alsam ein chol ### daz noch snellen heleden stvende in hohgeciten wol
###### 364 | ### voz Arabischem golde vil gesteins scein ### der frovwen vnmvoze div newas niht chlein ### inre siben wochen bereiten si div chleit ### do was ovch ir gewæfen den gvoten rechen bereit
###### 365 | ### Do si bereitet warn do was in v^f den Rin ### gemachet flizechlichen ein starchez sciffelin ### daz si tragen solde vol nider an den sê ### den edelen ivnchfrovwon was von arbeiten we
| ### Do sagte man den rechen in wæren nv bereit ### div si da fveren solden ir zierlichen chleit ### also si da gerten daz was nv getan ### done wolden si niht langer bi dem Rine bestan
###### 367 | ### Nach den hergesellen wart ein bote gesant ### ob si wolden scovwen niwez ir gewant ### ob ez den helden wære ce chvrz vnd ovch ze lanch ### ez was inrehter maze des sagten si den frovwen danch
###### 368 | ### Fver alle di si chomn di mvosen in des iehn ### daz si cer werlde heten bezers niht gesehn ### des mohten sise gerne da zehove tragn ### von bezer rechen wæte chvnde niemn niht gesagn
###### 369 | ### Vil groezliche danchen wart do niht verdeit ### do gerten vrlovbes di helde vil gemeit ### in riterlichen zvhten di herrn taten daz ### des wrden liehtiv ovgen von wein trveb vn– naz
| ### <Si> sprach vil lieber brvoder ir moehtet noh bestan ### vnt wrbet ander frovwen daz hiez ich wol getan ### da iv so sere enwage <stvende> niht der lip ### ir mvgt hie naher vinden ein also hoch geborn wip
###### 371 | ### Ich wæn in sagt ir herce daz in da von geschach ### si weinten al geliche swaz iemn gesprach ### ir golt in vor den brvesten wart von trahen sal ### di vielen in genote von den ovgen hin ce tal
| ### <Si> sprach herre Sivrit lat iv bevolhen sin ### v^f triwoe vn– v^f genade den lieben brvoder min ### daz im iht gewerre [307a] in Prvnhilde lant ### daz lobte der vil chvene infrovn Chrimhilde hant
###### 373 | ### Do sprach der degen riche ob mir min lebn bestat ### so svlt ir aller sorgen frovwe habn rat ### ich bringen iv gesvnden her wider <anden> Rin ### daz wizet sicherlichen im neich daz scoene magedin
| ### Er golt varwen scilde man trvog in vof den sant ### vn– braht inzvo zin allez ir gewant ### ir ross hiez man in ciehen si wolden riten dan ### da <wart> von scoenen frovwen vil michel weinen getan
###### 375 | ### Do stvonden in den venstern div minnechlichen chint ### ir sciff mit dem segele daz rvort ein hoher wint ### di stolzen hergeselln di sazen v^f den rin ### do sprach der kvnech Gvnther wer sol nv sciff meister sin
###### 376 | ### Daz wil ich sprach Sivrit ich chan ivch vf <der> flvot ### hinnen wol gefveren daz wizzet <helde> gvot ### di rehten wazer strazen di sint mir wol bechant ### si scieden vroelichen voz der Bvrgonden lant
###### 377 | ### Sivrit do balde eine scalten gewan ### von stade begvnde schieben der chreftige man ### Gvnther der chvene ein rvoder selbe nam ### do hvoben sich von lande di snellen riter lobesam
###### 378 | ### <· i> fvorten riche spise dar zvo vil gvoten win ### den besten den man <chvnde> vinden vmben Rin ### ir ross div stvonden scone si heten gvot gemach ### ir sciff daz gie vil ebene vil lvzel leides in gescach
###### 379 | ### Ir vil starchen segelseil div wrden in gestraht ### si fvoren zweinzech mile ê daz ez wrde naht ### mit eime gvotem winde nider gegn dem sê ### ir starchez arbeiten tet sit den hohgemvoten wê
###### 380 | ### An dem zwelften morgen so wir <hoeren> sagen ### heten si di winde verre dan getragen ### gegen Isensteine in Prvnhilde lant ### <daz> was ir deheinem niwan Sivride erchant
###### 381 | ### <· o> der kvnec Gvnther so vil der bvrge sach ### vn– ovch di witen marche wie balde er do sprach ### sagt mir friwent Sivrit ist iv daz bechant ### wes sint dise bvrge vn– ovch daz herliche lant
###### 382 | ### Des antwrte Sivrit ez ist mir wol bechant ### ez ist Prvnhilde livte vn– lant ### vn– Isenstein div veste als ir mich hortet iehn ### da mvget ir noch hivte vil scoener frovwen gesehn
###### 383 | ### Vnt wil iv helden raten ir habt einen mvot ### ir ieht geliche ia dvnchent ez mich gvot ### swenne wir noch hivte fvr Prvnhilde gan ### so mvezen wir mit sorgen vor der chvneginne stan
###### 384 | ### <· o> wir di minnechlichen bi ir gesinde sehn ### so svlt ir helde mære [30b] wan einer rede iehn ### Gvnther si min herre vn– ich si sin man ### des er da hat gedingen daz wirt allez getan
###### 385 | ### Des waren si bereite swaz er si loben hiez ### dvrh ir vbermvete ir deheiner ez niht liez ### si iahen swes er wolde da von in wol gescach ### do der kvnech Gvnther di scoenen Prvnhilde sach
###### 386 | ### Iane lob ihz niht so verre dvrch die liebe din ### so dvrch dine swester daz scoene magedin ### div ist mir sam min sele vn– so min selbes lip ### ich wil daz gerne dienen daz si werde min wip

<<< Übersicht <<< vorige Seite nächste Seite >>>